AuthyraLogging mixin

Mixin for easy logging in classes

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logDebug(String message, [dynamic data]) → void
logError(String message, [dynamic error, StackTrace? stackTrace]) → void
logInfo(String message, [dynamic data]) → void
logWarning(String message, [dynamic data]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited