LogLevel enum

Log levels for Authyra

Inheritance
Available extensions

Values

debug → const LogLevel
const LogLevel(0, '🔍', 'DEBUG')
info → const LogLevel
const LogLevel(1, 'â„šī¸', 'INFO')
warning → const LogLevel
const LogLevel(2, 'âš ī¸', 'WARNING')
error → const LogLevel
const LogLevel(3, '❌', 'ERROR')

Properties

emoji → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
label → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.