AuthyraLogger class
Authyra logging utility
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
configure(
LoggerConfig config) → void - Configure the logger
-
debug(
String message, [dynamic data]) → void -
disable(
) → void -
enable(
) → void -
error(
String message, [dynamic error, StackTrace? stackTrace]) → void - Log error message
-
info(
String message, [dynamic data]) → void -
setMinLevel(
LogLevel level) → void -
warning(
String message, [dynamic data]) → void