LogLevel enum
Log levels for Authyra
Values
Properties
- emoji â String
-
final
- hashCode â int
-
The hash code for this object.
no setterinherited
- index â int
-
A numeric identifier for the enumerated value.
no setterinherited
- label â String
-
final
- name â String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType â Type
-
A representation of the runtime type of the object.
no setterinherited
- value â int
-
final
Methods
-
noSuchMethod(
Invocation invocation) â dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) â String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) â bool -
The equality operator.
inherited