LoggerConfig class
Logger configuration
Constructors
Properties
- customLogger → void Function(String message, LogLevel level)?
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minLevel → LogLevel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showEmoji → bool
-
final
- showTimestamp → bool
-
final
Methods
-
copyWith(
{bool? enabled, LogLevel? minLevel, bool? showTimestamp, bool? showEmoji, void customLogger(String message, LogLevel level)?}) → LoggerConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited